@@ -6,9 +6,9 @@
 
 #define QT_FEATURE_videotoolbox 1
 
-#define QT_FEATURE_evr -1
-
 #define QT_FEATURE_mmrenderer -1
 
+#define QT_FEATURE_native_android_backend -1
+
 #define QT_FEATURE_pulseaudio 1
 
